/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package xyz.zhouxy.plusone.oss;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.util.StringUtils;

import xyz.zhouxy.plusone.commons.util.AssertTools;

/**
 * S3 配置
 *
 * @author <a href="http://zhouxy.xyz:3000/ZhouXY108}">ZhouXY</a>
 */
@ConfigurationProperties("plusone.s3")
public class S3Properties {

    private OSSType type;
    private Protocol protocol;
    private String endpoint;
    private Integer port;
    private String accessKey;
    private String secretKey;
    private String region;

    /**
     * @return the type
     */
    public OSSType getType() {
        return type;
    }

    /**
     * @param type the type to set
     */
    public void setType(OSSType type) {
        this.type = type;
    }

    /**
     * @return the protocol
     */
    public Protocol getProtocol() {
        return protocol;
    }

    /**
     * @param protocol the protocol to set
     */
    public void setProtocol(Protocol protocol) {
        this.protocol = protocol;
    }

    /**
     * @return the endpoint
     */
    public String getEndpoint() {
        return endpoint;
    }

    /**
     * @param endpoint the endpoint to set
     */
    public void setEndpoint(String endpoint) {
        AssertTools.checkArgument(StringUtils.hasText(endpoint), "Property \"endpoint\" must has text.");
        this.endpoint = endpoint;
    }

    /**
     * @return the port
     */
    public Integer getPort() {
        return port;
    }

    /**
     * @param port the port to set
     */
    public void setPort(Integer port) {
        this.port = port;
    }

    /**
     * @return the accessKey
     */
    public String getAccessKey() {
        return accessKey;
    }

    /**
     * @param accessKey the accessKey to set
     */
    public void setAccessKey(String accessKey) {
        AssertTools.checkArgument(StringUtils.hasText(accessKey), "Property \"accessKey\" must has text.");
        this.accessKey = accessKey;
    }

    /**
     * @return the secretKey
     */
    public String getSecretKey() {
        return secretKey;
    }

    /**
     * @param secretKey the secretKey to set
     */
    public void setSecretKey(String secretKey) {
        AssertTools.checkArgument(StringUtils.hasText(secretKey), "Property \"secretKey\" must has text.");
        this.secretKey = secretKey;
    }

    /**
     * @return the region
     */
    public String getRegion() {
        return region;
    }

    /**
     * @param region the region to set
     */
    public void setRegion(String region) {
        this.region = region;
    }

    public boolean isSecure() {
        return this.protocol != null && this.protocol == Protocol.HTTPS;
    }
}
