package xyz.zhouxy.plusone.oss;

import static org.junit.jupiter.api.Assertions.*;

import java.time.Duration;
import java.util.concurrent.TimeUnit;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import io.minio.GetPresignedObjectUrlArgs;
import io.minio.MinioClient;
import io.minio.http.Method;
import lombok.extern.slf4j.Slf4j;

@SpringBootTest
@Slf4j
public class PlusoneOssTestApplicationTests {

    @Autowired
    PlusoneS3AutoConfiguration s3Config;


    @Test
    void testListBuckets() throws Exception {
        try (MinioClient minioClient = s3Config.ossClient()) {
            minioClient.listBuckets().forEach(bucket -> {
                log.info("Bucket - [name: {}, creationDate: {}]", bucket.name(), bucket.creationDate());
            });
        } catch (Exception e) {
            log.error("测试失败", e);
            throw e;
        }
    }

    @Test
    void testMinIO() throws Exception {
        try (MinioClient ossClient = s3Config.ossClient()) {
            var url = ossClient.getPresignedObjectUrl(GetPresignedObjectUrlArgs.builder()
                    .bucket("code108-1300048601")
                    .object("plusone/表结构.xlsx")
                    .expiry(10, TimeUnit.MINUTES)
                    .method(Method.GET)
                    .build());
            logObj(url);
        } catch (Exception e) {
            log.info("测试失败", e);
            throw e;
        }
    }

    static void logObj(Object obj) {
        log.info("{}", obj);
    }
}
